==> apache-streampipes-0.95.1-source-release.zip: apache-streampipes-0.95.1/streampipes-connect-shared/src/main/java/org/apache/streampipes/connect/shared/preprocessing/transform/schema/AddValueTransformationRule.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.connect.shared.preprocessing.transform.schema;

import org.apache.streampipes.connect.shared.DatatypeUtils;
import org.apache.streampipes.connect.shared.preprocessing.transform.TransformationRule;

import java.util.Map;

public class AddValueTransformationRule implements TransformationRule {

  private final String runtimeKey;
  private final String value;
  private final String datatype;

  public AddValueTransformationRule(String runtimeKey,
                                    String value,
                                    String datatype) {
    this.runtimeKey = runtimeKey;
    this.value = value;
    this.datatype = datatype;
  }

  @Override
  public Map<String, Object> apply(Map<String, Object> event) {
    var convertedValue = DatatypeUtils.convertValue(value, datatype);
    event.put(runtimeKey, convertedValue);
    return event;
  }

}

==> apache-streampipes-0.98.0-source-release.zip: apache-streampipes-0.98.0/streampipes-connect-shared/src/main/java/org/apache/streampipes/connect/shared/preprocessing/transform/schema/AddValueTransformationRule.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.streampipes.connect.shared.preprocessing.transform.schema;

import org.apache.streampipes.connect.shared.DatatypeUtils;
import org.apache.streampipes.extensions.api.connect.TransformationRule;

import java.util.Map;

public class AddValueTransformationRule implements TransformationRule {

  private final String runtimeKey;
  private final String value;
  private final String datatype;

  public AddValueTransformationRule(String runtimeKey,
                                    String value,
                                    String datatype) {
    this.runtimeKey = runtimeKey;
    this.value = value;
    this.datatype = datatype;
  }

  @Override
  public Map<String, Object> apply(Map<String, Object> event) {
    var convertedValue = DatatypeUtils.convertValue(value, datatype);
    event.put(runtimeKey, convertedValue);
    return event;
  }

}
